==> openshift-serverless-logic-1.26.0-src.zip: openshift-serverless-logic-1.26.0.GA-src/org.kie.kogito-kogito-apps-1.30.0.Final/ui-packages/packages/process-list/src/embedded/ProcessListChannelApiImpl.ts <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {
  ProcessListChannelApi,
  ProcessInstanceFilter,
  ProcessListDriver,
  SortBy
} from '../api';
import {
  BulkProcessInstanceActionResponse,
  OperationType,
  ProcessInstance
} from '@kogito-apps/management-console-shared';

export class ProcessListChannelApiImpl implements ProcessListChannelApi {
  constructor(private readonly driver: ProcessListDriver) {}

  processList__initialLoad(
    filter: ProcessInstanceFilter,
    sortBy: SortBy
  ): Promise<void> {
    return this.driver.initialLoad(filter, sortBy);
  }

  processList__openProcess(process: ProcessInstance): Promise<void> {
    return this.driver.openProcess(process);
  }

  processList__applyFilter(filter: ProcessInstanceFilter): Promise<void> {
    return this.driver.applyFilter(filter);
  }

  processList__applySorting(sortBy: SortBy): Promise<void> {
    return this.driver.applySorting(sortBy);
  }

  processList__handleProcessSkip(
    processInstance: ProcessInstance
  ): Promise<void> {
    return this.driver.handleProcessSkip(processInstance);
  }
  processList__handleProcessRetry(
    processInstance: ProcessInstance
  ): Promise<void> {
    return this.driver.handleProcessRetry(processInstance);
  }
  processList__handleProcessAbort(
    processInstance: ProcessInstance
  ): Promise<void> {
    return this.driver.handleProcessAbort(processInstance);
  }
  processList__handleProcessMultipleAction(
    processInstances: ProcessInstance[],
    operationType: OperationType
  ): Promise<BulkProcessInstanceActionResponse> {
    return this.driver.handleProcessMultipleAction(
      processInstances,
      operationType
    );
  }
  processList__query(
    offset: number,
    limit: number
  ): Promise<ProcessInstance[]> {
    return this.driver.query(offset, limit);
  }

  processList__getChildProcessesQuery(
    rootProcessInstanceId: string
  ): Promise<ProcessInstance[]> {
    return this.driver.getChildProcessesQuery(rootProcessInstanceId);
  }
}

==> openshift-serverless-logic-1.29.0-src.zip: openshift-serverless-logic-1.29.0.GA-src/org.kie.kogito-kogito-apps-1.38.0.Final/ui-packages/packages/process-list/src/embedded/ProcessListChannelApiImpl.ts <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {
  ProcessListChannelApi,
  ProcessInstanceFilter,
  ProcessListDriver,
  SortBy
} from '../api';
import {
  BulkProcessInstanceActionResponse,
  OperationType,
  ProcessInstance
} from '@kogito-apps/management-console-shared';

export class ProcessListChannelApiImpl implements ProcessListChannelApi {
  constructor(private readonly driver: ProcessListDriver) {}

  processList__initialLoad(
    filter: ProcessInstanceFilter,
    sortBy: SortBy
  ): Promise<void> {
    return this.driver.initialLoad(filter, sortBy);
  }

  processList__openProcess(process: ProcessInstance): Promise<void> {
    return this.driver.openProcess(process);
  }

  processList__applyFilter(filter: ProcessInstanceFilter): Promise<void> {
    return this.driver.applyFilter(filter);
  }

  processList__applySorting(sortBy: SortBy): Promise<void> {
    return this.driver.applySorting(sortBy);
  }

  processList__handleProcessSkip(
    processInstance: ProcessInstance
  ): Promise<void> {
    return this.driver.handleProcessSkip(processInstance);
  }
  processList__handleProcessRetry(
    processInstance: ProcessInstance
  ): Promise<void> {
    return this.driver.handleProcessRetry(processInstance);
  }
  processList__handleProcessAbort(
    processInstance: ProcessInstance
  ): Promise<void> {
    return this.driver.handleProcessAbort(processInstance);
  }
  processList__handleProcessMultipleAction(
    processInstances: ProcessInstance[],
    operationType: OperationType
  ): Promise<BulkProcessInstanceActionResponse> {
    return this.driver.handleProcessMultipleAction(
      processInstances,
      operationType
    );
  }
  processList__query(
    offset: number,
    limit: number
  ): Promise<ProcessInstance[]> {
    return this.driver.query(offset, limit);
  }

  processList__getChildProcessesQuery(
    rootProcessInstanceId: string
  ): Promise<ProcessInstance[]> {
    return this.driver.getChildProcessesQuery(rootProcessInstanceId);
  }

  processList__openTriggerCloudEvent(processInstance?: ProcessInstance): void {
    this.driver.openTriggerCloudEvent(processInstance);
  }
}
